@@ -1,5 +1,7 @@
 import warnings
+
 warnings.warn(
     "'pydm.PyQt' is deprecated, "
     "please directly import from the 'qtpy' module.  "
-    "pydm.PyQt will be removed in PyDM v1.8")
\ No newline at end of file
+    "pydm.PyQt will be removed in PyDM v1.8"
+)
