@@ -1,11 +1,6 @@
 import os
 
-__all__ = ['DEFAULT_PROTOCOL',
-           'DESIGNER_ONLINE',
-           'STYLESHEET',
-           'STYLESHEET_INCLUDE_DEFAULT',
-           'CONFIRM_QUIT'
-           ]
+__all__ = ["DEFAULT_PROTOCOL", "DESIGNER_ONLINE", "STYLESHEET", "STYLESHEET_INCLUDE_DEFAULT", "CONFIRM_QUIT"]
 
 
 DEFAULT_PROTOCOL = os.getenv("PYDM_DEFAULT_PROTOCOL")
