@@ -1,24 +1,37 @@
 import os
+import pytest
 import logging
 
-
+from ... import config
 from ...utilities import stylesheet
 from qtpy.QtWidgets import QApplication
 
 # The path to the stylesheet used in these unit tests
 test_stylesheet_path = os.path.join(
-    os.path.dirname(os.path.realpath(__file__)),
-    "..", "test_data", "global_stylesheet.css")
+    os.path.dirname(os.path.realpath(__file__)), "..", "test_data", "global_stylesheet.css"
+)
 
 
-def test_stylesheet_apply(qtbot):
-    # Backup of the variable
+@pytest.fixture(scope="function")
+def save_and_restore_pydm_stylesheet():
+    """
+    A fixture for ensuring that modifications to the PYDM_STYLESHEET environment variable are restored
+    even if the test fails. This will prevent any impact to the user's environment, as well as future tests in the run.
+    """
+    # Back up the stylesheet related variables so they can be restored after the test
     env_backup = os.getenv("PYDM_STYLESHEET", None)
-
-    # Backup of the GLOBAL_STYLESHEET path
-    backup_global = stylesheet.GLOBAL_STYLESHEET
-
+    backup_global_style_path = stylesheet.GLOBAL_STYLESHEET
     os.environ["PYDM_STYLESHEET"] = ""
+
+    yield
+
+    # Restore the user's original stylesheet
+    if env_backup:
+        os.environ["PYDM_STYLESHEET"] = env_backup
+    stylesheet.GLOBAL_STYLESHEET = backup_global_style_path
+
+
+def test_stylesheet_apply(qtbot, save_and_restore_pydm_stylesheet):
     assert os.getenv("PYDM_STYLESHEET", None) == ""
 
     # Retrieve instance of the application so we can test with it
@@ -33,9 +46,6 @@ def test_stylesheet_apply(qtbot):
 
     assert app.styleSheet() is not None
 
-    # Backup of the GLOBAL_STYLESHEET path
-    backup_global = stylesheet.GLOBAL_STYLESHEET
-
     stylesheet.clear_cache()
     # Exercise when there is no stylesheet available
     stylesheet.GLOBAL_STYLESHEET = "invalid_file.none"
@@ -47,20 +57,8 @@ def test_stylesheet_apply(qtbot):
 
     assert not app.styleSheet()
 
-    # Restore the variable
-    if env_backup:
-        os.environ["PYDM_STYLESHEET"] = env_backup
-    stylesheet.GLOBAL_STYLESHEET = backup_global
 
-
-def test_stylesheet_get_style_data(caplog):
-    # Backup of the variable
-    env_backup = os.getenv("PYDM_STYLESHEET", None)
-
-    # Backup of the GLOBAL_STYLESHEET path
-    backup_global = stylesheet.GLOBAL_STYLESHEET
-
-    os.environ["PYDM_STYLESHEET"] = ""
+def test_stylesheet_get_style_data(caplog, save_and_restore_pydm_stylesheet):
     assert os.getenv("PYDM_STYLESHEET", None) == ""
 
     with caplog.at_level(logging.DEBUG):
@@ -127,10 +125,8 @@ def test_stylesheet_get_style_data(caplog):
         ret = stylesheet._get_style_data()
 
         # Make sure logging capture the error, and have the correct error message
-        assert len(caplog.records) == 1
+        if not config.STYLESHEET:
+            assert len(caplog.records) == 1
+        else:
+            assert len(caplog.records) == 2  # Extra message about existing stylesheet
         assert "Cannot find the default stylesheet" in caplog.text
-
-    # Restore the variable
-    if env_backup:
-        os.environ["PYDM_STYLESHEET"] = env_backup
-    stylesheet.GLOBAL_STYLESHEET = backup_global
