@@ -1,18 +1,27 @@
 # Unit Tests for the Color Map
 
 
-import pytest
-
 import numpy as np
 
-from ...widgets.colormaps import PyDMColorMap, _magma_data, _inferno_data, _plasma_data, _viridis_data, _jet_data, \
-    _monochrome_data, _hot_data, cmaps, magma, inferno, plasma, viridis, jet, monochrome, hot, cmap_names
+from ...widgets.colormaps import (
+    PyDMColorMap,
+    cmaps,
+    magma,
+    inferno,
+    plasma,
+    viridis,
+    jet,
+    monochrome,
+    hot,
+    cmap_names,
+)
 
 
 # --------------------
 # POSITIVE TEST CASES
 # --------------------
 
+
 def test_construct():
     """
     Test the construction of the ColorMaps, and the creations of auxiliary helper objects.
