@@ -6,34 +6,45 @@ import pytest
 
 from qtpy.QtGui import QColor, QBrush, QPixmap
 from qtpy.QtWidgets import QApplication
-from qtpy.QtCore import Property, Qt, QPoint, QSize
+from qtpy.QtCore import Qt, QSize
 from qtpy.QtDesigner import QDesignerFormWindowInterface
 
 from ...widgets.base import PyDMWidget
-from ...widgets.drawing import (deg_to_qt, qt_to_deg, PyDMDrawing,
-                                PyDMDrawingLine, PyDMDrawingImage,
-                                PyDMDrawingRectangle, PyDMDrawingTriangle,
-                                PyDMDrawingEllipse,
-                                PyDMDrawingCircle, PyDMDrawingArc,
-                                PyDMDrawingPie, PyDMDrawingChord,
-                                PyDMDrawingPolygon, PyDMDrawingPolyline,
-                                PyDMDrawingIrregularPolygon)
-
-from ...utilities.stylesheet import apply_stylesheet
+from ...widgets.drawing import (
+    deg_to_qt,
+    qt_to_deg,
+    PyDMDrawing,
+    PyDMDrawingLine,
+    PyDMDrawingImage,
+    PyDMDrawingRectangle,
+    PyDMDrawingTriangle,
+    PyDMDrawingEllipse,
+    PyDMDrawingCircle,
+    PyDMDrawingArc,
+    PyDMDrawingPie,
+    PyDMDrawingChord,
+    PyDMDrawingPolygon,
+    PyDMDrawingPolyline,
+    PyDMDrawingIrregularPolygon,
+)
 
 
 # --------------------
 # POSITIVE TEST CASES
 # --------------------
 
+
 # # -------------
 # # PyDMDrawing
 # # -------------
-@pytest.mark.parametrize("deg, expected_qt_deg", [
-    (0, 0),
-    (1, 16),
-    (-1, -16),
-])
+@pytest.mark.parametrize(
+    "deg, expected_qt_deg",
+    [
+        (0, 0),
+        (1, 16),
+        (-1, -16),
+    ],
+)
 def test_deg_to_qt(deg, expected_qt_deg):
     """
     Test the conversion from degrees to Qt degrees.
@@ -53,29 +64,23 @@ def test_deg_to_qt(deg, expected_qt_deg):
     assert deg_to_qt(deg) == expected_qt_deg
 
 
-@pytest.mark.parametrize("qt_deg, expected_deg", [
-    (0, 0),
-    (16, 1),
-    (-16, -1),
-    (-32.0, -2),
-    (16.16, 1.01)
-])
+@pytest.mark.parametrize("qt_deg, expected_deg", [(0, 0), (16, 1), (-16, -1), (-32.0, -2), (16.16, 1.01)])
 def test_qt_to_deg(qt_deg, expected_deg):
     """
-       Test the conversion from Qt degrees to degrees.
+    Test the conversion from Qt degrees to degrees.
 
-       Expectations:
-       The angle measurement in Qt degrees is converted correctly to degrees, which are 16 times less than the Qt degree
-       value, i.e. 1 Qt degree = 1/16 degree
+    Expectations:
+    The angle measurement in Qt degrees is converted correctly to degrees, which are 16 times less than the Qt degree
+    value, i.e. 1 Qt degree = 1/16 degree
 
-       Parameters
-       ----------
-       qt_deg : int, float
-           The angle value in Qt degrees
+    Parameters
+    ----------
+    qt_deg : int, float
+        The angle value in Qt degrees
 
-       expected_deg : int, floag
-           The expected degrees after the conversion
-       """
+    expected_deg : int, floag
+        The expected degrees after the conversion
+    """
     assert qt_to_deg(qt_deg) == expected_deg
 
 
@@ -121,10 +126,13 @@ def test_pydmdrawing_sizeHint(qtbot):
     assert pydm_drawing.sizeHint() == QSize(100, 100)
 
 
-@pytest.mark.parametrize("alarm_sensitive_content", [
-    True,
-    False,
-])
+@pytest.mark.parametrize(
+    "alarm_sensitive_content",
+    [
+        True,
+        False,
+    ],
+)
 def test_pydmdrawing_paintEvent(qtbot, signals, alarm_sensitive_content):
     """
     Test the paintEvent handling of the widget. This test method will also execute PyDMDrawing alarm_severity_changed
@@ -133,7 +141,8 @@ def test_pydmdrawing_paintEvent(qtbot, signals, alarm_sensitive_content):
     Expectations:
     The paintEvent will be triggered, and the widget's brush color is correctly set.
 
-    NOTE: This test depends on the default stylesheet having different values for 'qproperty-brush' for different alarm states of PyDMDrawing.
+    NOTE: This test depends on the default stylesheet having different values for 'qproperty-brush' for different
+    alarm states of PyDMDrawing.
 
     Parameters
     ----------
@@ -147,7 +156,7 @@ def test_pydmdrawing_paintEvent(qtbot, signals, alarm_sensitive_content):
     QApplication.instance().make_main_window()
     main_window = QApplication.instance().main_window
     qtbot.addWidget(main_window)
-    pydm_drawing = PyDMDrawing(parent=main_window, init_channel='fake://tst')
+    pydm_drawing = PyDMDrawing(parent=main_window, init_channel="fake://tst")
     qtbot.addWidget(pydm_drawing)
     pydm_drawing.alarmSensitiveContent = alarm_sensitive_content
     brush_before = pydm_drawing.brush.color().name()
@@ -161,13 +170,10 @@ def test_pydmdrawing_paintEvent(qtbot, signals, alarm_sensitive_content):
         assert brush_before == brush_after
 
 
-@pytest.mark.parametrize("widget_width, widget_height, expected_results", [
-    (4.0, 4.0, (2.0, 2.0)),
-    (1.0, 1.0, (0.5, 0.5)),
-    (0, 0, (0, 0))
-])
-def test_pydmdrawing_get_center(qtbot, monkeypatch, widget_width, widget_height,
-                                expected_results):
+@pytest.mark.parametrize(
+    "widget_width, widget_height, expected_results", [(4.0, 4.0, (2.0, 2.0)), (1.0, 1.0, (0.5, 0.5)), (0, 0, (0, 0))]
+)
+def test_pydmdrawing_get_center(qtbot, monkeypatch, widget_width, widget_height, expected_results):
     """
     Test the calculation of the widget's center from its width and height.
 
@@ -201,73 +207,43 @@ def test_pydmdrawing_get_center(qtbot, monkeypatch, widget_width, widget_height,
     [
         # Zero rotation, with typical width, height, pen_width, and variable max_size, has_border, and force_no_pen
         # width > height
-        (25.53, 10.35, 0.0, 2, True, True, True,
-         (-12.765, -5.175, 25.53, 10.35)),
-        (25.53, 10.35, 0.0, 2, True, True, False,
-         (-10.765, -3.175, 21.53, 6.35)),
-        (25.53, 10.35, 0.0, 2, True, False, True,
-         (-12.765, -5.175, 25.53, 10.35)),
-        (25.53, 10.35, 0.0, 2, True, False, False,
-         (-10.765, -3.175, 21.53, 6.35)),
-        (25.53, 10.35, 0.0, 2, False, True, True,
-         (-12.765, -5.175, 25.53, 10.35)),
-        (25.53, 10.35, 0.0, 2, False, True, False,
-         (-12.765, -5.175, 25.53, 10.35)),
-        (25.53, 10.35, 0.0, 2, False, False, True,
-         (-12.765, -5.175, 25.53, 10.35)),
-
+        (25.53, 10.35, 0.0, 2, True, True, True, (-12.765, -5.175, 25.53, 10.35)),
+        (25.53, 10.35, 0.0, 2, True, True, False, (-10.765, -3.175, 21.53, 6.35)),
+        (25.53, 10.35, 0.0, 2, True, False, True, (-12.765, -5.175, 25.53, 10.35)),
+        (25.53, 10.35, 0.0, 2, True, False, False, (-10.765, -3.175, 21.53, 6.35)),
+        (25.53, 10.35, 0.0, 2, False, True, True, (-12.765, -5.175, 25.53, 10.35)),
+        (25.53, 10.35, 0.0, 2, False, True, False, (-12.765, -5.175, 25.53, 10.35)),
+        (25.53, 10.35, 0.0, 2, False, False, True, (-12.765, -5.175, 25.53, 10.35)),
         # width < height
-        (10.35, 25.53, 0.0, 2, True, True, True,
-         (-5.175, -12.765, 10.35, 25.53)),
-        (10.35, 25.53, 0.0, 2, True, True, False,
-         (-3.175, -10.765, 6.35, 21.53)),
-        (10.35, 25.53, 0.0, 2, True, False, True,
-         (-5.175, -12.765, 10.35, 25.53)),
-        (10.35, 25.53, 0.0, 2, True, False, False,
-         (-3.175, -10.765, 6.35, 21.53)),
-        (10.35, 25.53, 0.0, 2, False, True, True,
-         (-5.175, -12.765, 10.35, 25.53)),
-        (10.35, 25.53, 0.0, 2, False, True, False,
-         (-5.175, -12.765, 10.35, 25.53)),
-        (10.35, 25.53, 0.0, 2, False, False, True,
-         (-5.175, -12.765, 10.35, 25.53)),
-
+        (10.35, 25.53, 0.0, 2, True, True, True, (-5.175, -12.765, 10.35, 25.53)),
+        (10.35, 25.53, 0.0, 2, True, True, False, (-3.175, -10.765, 6.35, 21.53)),
+        (10.35, 25.53, 0.0, 2, True, False, True, (-5.175, -12.765, 10.35, 25.53)),
+        (10.35, 25.53, 0.0, 2, True, False, False, (-3.175, -10.765, 6.35, 21.53)),
+        (10.35, 25.53, 0.0, 2, False, True, True, (-5.175, -12.765, 10.35, 25.53)),
+        (10.35, 25.53, 0.0, 2, False, True, False, (-5.175, -12.765, 10.35, 25.53)),
+        (10.35, 25.53, 0.0, 2, False, False, True, (-5.175, -12.765, 10.35, 25.53)),
         # width == height
-        (
-        10.35, 10.35, 0.0, 2, True, True, True, (-5.175, -5.175, 10.35, 10.35)),
+        (10.35, 10.35, 0.0, 2, True, True, True, (-5.175, -5.175, 10.35, 10.35)),
         (10.35, 10.35, 0.0, 2, True, True, False, (-3.175, -3.175, 6.35, 6.35)),
-        (10.35, 10.35, 0.0, 2, True, False, True,
-         (-5.175, -5.175, 10.35, 10.35)),
-        (
-        10.35, 10.35, 0.0, 2, True, False, False, (-3.175, -3.175, 6.35, 6.35)),
-        (10.35, 10.35, 0.0, 2, False, True, True,
-         (-5.175, -5.175, 10.35, 10.35)),
-        (10.35, 10.35, 0.0, 2, False, True, False,
-         (-5.175, -5.175, 10.35, 10.35)),
-        (10.35, 10.35, 0.0, 2, False, False, True,
-         (-5.175, -5.175, 10.35, 10.35)),
-
+        (10.35, 10.35, 0.0, 2, True, False, True, (-5.175, -5.175, 10.35, 10.35)),
+        (10.35, 10.35, 0.0, 2, True, False, False, (-3.175, -3.175, 6.35, 6.35)),
+        (10.35, 10.35, 0.0, 2, False, True, True, (-5.175, -5.175, 10.35, 10.35)),
+        (10.35, 10.35, 0.0, 2, False, True, False, (-5.175, -5.175, 10.35, 10.35)),
+        (10.35, 10.35, 0.0, 2, False, False, True, (-5.175, -5.175, 10.35, 10.35)),
         # Variable rotation, max_size, and force_no_pen, has_border is True
-        (25.53, 10.35, 45.0, 2, True, True, True,
-         (-5.207, -2.111, 10.415, 4.222)),
-        (25.53, 10.35, 145.0, 2, True, True, True,
-         (-5.714, -2.316, 11.428, 4.633)),
-        (25.53, 10.35, 90.0, 2, True, True, False,
-         (-3.175, -0.098, 6.35, 0.196)),
-        (25.53, 10.35, 180.0, 2, True, False, True,
-         (-12.765, -5.175, 25.53, 10.35)),
-        (25.53, 10.35, 270.0, 2, True, False, False,
-         (-10.765, -3.175, 21.53, 6.35)),
-        (25.53, 10.35, 360.0, 2, False, True, True,
-         (-12.765, -5.175, 25.53, 10.35)),
-        (25.53, 10.35, 0.72, 2, False, True, False,
-         (-12.382, -5.02, 24.764, 10.04)),
-        (25.53, 10.35, 71.333, 2, False, False, True,
-         (-12.765, -5.175, 25.53, 10.35)),
-    ])
-def test_pydmdrawing_get_bounds(qtbot, monkeypatch, width, height, rotation_deg,
-                                pen_width, has_border, max_size,
-                                force_no_pen, expected):
+        (25.53, 10.35, 45.0, 2, True, True, True, (-5.207, -2.111, 10.415, 4.222)),
+        (25.53, 10.35, 145.0, 2, True, True, True, (-5.714, -2.316, 11.428, 4.633)),
+        (25.53, 10.35, 90.0, 2, True, True, False, (-3.175, -0.098, 6.35, 0.196)),
+        (25.53, 10.35, 180.0, 2, True, False, True, (-12.765, -5.175, 25.53, 10.35)),
+        (25.53, 10.35, 270.0, 2, True, False, False, (-10.765, -3.175, 21.53, 6.35)),
+        (25.53, 10.35, 360.0, 2, False, True, True, (-12.765, -5.175, 25.53, 10.35)),
+        (25.53, 10.35, 0.72, 2, False, True, False, (-12.382, -5.02, 24.764, 10.04)),
+        (25.53, 10.35, 71.333, 2, False, False, True, (-12.765, -5.175, 25.53, 10.35)),
+    ],
+)
+def test_pydmdrawing_get_bounds(
+    qtbot, monkeypatch, width, height, rotation_deg, pen_width, has_border, max_size, force_no_pen, expected
+):
     """
     Test the useful area calculations and compare the resulted tuple to the expected one.
 
@@ -302,19 +278,21 @@ def test_pydmdrawing_get_bounds(qtbot, monkeypatch, width, height, rotation_deg,
         monkeypatch.setattr(PyDMDrawing, "has_border", lambda *args: False)
 
     calculated_bounds = pydm_drawing.get_bounds(max_size, force_no_pen)
-    calculated_bounds = tuple(
-        [round(x, 3) if isinstance(x, float) else x for x in calculated_bounds])
+    calculated_bounds = tuple([round(x, 3) if isinstance(x, float) else x for x in calculated_bounds])
     assert calculated_bounds == expected
 
 
-@pytest.mark.parametrize("pen_style, pen_width, expected_result", [
-    (Qt.NoPen, 0, False),
-    (Qt.NoPen, 1, False),
-    (Qt.SolidLine, 0, False),
-    (Qt.DashLine, 0, False),
-    (Qt.SolidLine, 1, True),
-    (Qt.DashLine, 10, True)
-])
+@pytest.mark.parametrize(
+    "pen_style, pen_width, expected_result",
+    [
+        (Qt.NoPen, 0, False),
+        (Qt.NoPen, 1, False),
+        (Qt.SolidLine, 0, False),
+        (Qt.DashLine, 0, False),
+        (Qt.SolidLine, 1, True),
+        (Qt.DashLine, 10, True),
+    ],
+)
 def test_pydmdrawing_has_border(qtbot, pen_style, pen_width, expected_result):
     """
     Test the determination whether the widget will be drawn with a border, taking into account the pen style and width
@@ -342,16 +320,18 @@ def test_pydmdrawing_has_border(qtbot, pen_style, pen_width, expected_result):
     assert pydm_drawing.has_border() == expected_result
 
 
-@pytest.mark.parametrize("width, height, expected_result", [
-    (10, 15, False),
-    (10.5, 22.333, False),
-    (-10.333, -10.332, False),
-    (10.333, 10.333, True),
-    (-20.777, -20.777, True),
-    (70, 70, True),
-])
-def test_pydmdrawing_is_square(qtbot, monkeypatch, width, height,
-                               expected_result):
+@pytest.mark.parametrize(
+    "width, height, expected_result",
+    [
+        (10, 15, False),
+        (10.5, 22.333, False),
+        (-10.333, -10.332, False),
+        (10.333, 10.333, True),
+        (-20.777, -20.777, True),
+        (70, 70, True),
+    ],
+)
+def test_pydmdrawing_is_square(qtbot, monkeypatch, width, height, expected_result):
     """
     Check if the widget has the same width and height values.
 
@@ -380,18 +360,20 @@ def test_pydmdrawing_is_square(qtbot, monkeypatch, width, height,
     assert pydm_drawing.is_square() == expected_result
 
 
-@pytest.mark.parametrize("width, height, rotation_deg, expected", [
-    (25.53, 10.35, 0.0, (25.53, 10.35)),
-    (10.35, 25.53, 0.0, (10.35, 25.53)),
-    (25.53, 10.35, 45.0, (10.415, 4.222)),
-    (10.35, 25.53, 45.0, (4.222, 10.415)),
-    (10.35, 25.53, 360.0, (10.35, 25.53)),
-    (10.35, 25.53, -45.0, (4.222, 10.415)),
-    (10.35, 25.53, -270.0, (4.196, 10.35)),
-    (10.35, 25.53, -360.0, (10.35, 25.53)),
-])
-def test_pydmdrawing_get_inner_max(qtbot, monkeypatch, width, height,
-                                   rotation_deg, expected):
+@pytest.mark.parametrize(
+    "width, height, rotation_deg, expected",
+    [
+        (25.53, 10.35, 0.0, (25.53, 10.35)),
+        (10.35, 25.53, 0.0, (10.35, 25.53)),
+        (25.53, 10.35, 45.0, (10.415, 4.222)),
+        (10.35, 25.53, 45.0, (4.222, 10.415)),
+        (10.35, 25.53, 360.0, (10.35, 25.53)),
+        (10.35, 25.53, -45.0, (4.222, 10.415)),
+        (10.35, 25.53, -270.0, (4.196, 10.35)),
+        (10.35, 25.53, -360.0, (10.35, 25.53)),
+    ],
+)
+def test_pydmdrawing_get_inner_max(qtbot, monkeypatch, width, height, rotation_deg, expected):
     """
     Test the calculation of the inner rectangle in a rotated rectangle.
 
@@ -421,9 +403,7 @@ def test_pydmdrawing_get_inner_max(qtbot, monkeypatch, width, height,
     monkeypatch.setattr(PyDMDrawing, "height", lambda *args: height)
 
     calculated_inner_max = pydm_drawing.get_inner_max()
-    calculated_inner_max = tuple(
-        [round(x, 3) if isinstance(x, float) else x for x in
-         calculated_inner_max])
+    calculated_inner_max = tuple([round(x, 3) if isinstance(x, float) else x for x in calculated_inner_max])
     assert calculated_inner_max == expected
 
 
@@ -477,10 +457,13 @@ def test_pydmdrawing_properties_and_setters(qtbot):
 # # ----------------
 # # PyDMDrawingLine
 # # ----------------
-@pytest.mark.parametrize("alarm_sensitive_content", [
-    True,
-    False,
-])
+@pytest.mark.parametrize(
+    "alarm_sensitive_content",
+    [
+        True,
+        False,
+    ],
+)
 def test_pydmdrawingline_draw_item(qtbot, signals, alarm_sensitive_content):
     """
     Test PyDMDrawingLine base class drawing handling.
@@ -498,7 +481,7 @@ def test_pydmdrawingline_draw_item(qtbot, signals, alarm_sensitive_content):
     alarm_sensitive_content : bool
         True if the widget will be redraw with a different color if an alarm is triggered; False otherwise
     """
-    pydm_drawingline = PyDMDrawingLine(init_channel='fake://tst')
+    pydm_drawingline = PyDMDrawingLine(init_channel="fake://tst")
     qtbot.addWidget(pydm_drawingline)
 
     pydm_drawingline.alarmSensitiveContent = alarm_sensitive_content
@@ -539,8 +522,7 @@ def test_pydmdrawingimage_construct(qtbot):
     assert pydm_drawingimage.filename == ""
 
     base_path = os.path.dirname(__file__)
-    test_file = os.path.join(base_path, '..', '..', '..', 'examples', 'drawing',
-                             'SLAC_logo.jpeg')
+    test_file = os.path.join(base_path, "..", "..", "..", "examples", "drawing", "SLAC_logo.jpeg")
     pydm_drawingimage2 = PyDMDrawingImage(filename=test_file)
     qtbot.addWidget(pydm_drawingimage2)
 
@@ -550,8 +532,7 @@ def test_pydmdrawingimage_construct(qtbot):
     pydm_drawingimage4 = PyDMDrawingImage(filename="foo")
     qtbot.addWidget(pydm_drawingimage4)
 
-    test_gif = os.path.join(base_path, '..', '..', '..', 'examples', 'drawing',
-                             'test.gif')
+    test_gif = os.path.join(base_path, "..", "..", "..", "examples", "drawing", "test.gif")
     pydm_drawingimage5 = PyDMDrawingImage(filename=test_gif)
     pydm_drawingimage5.movie_finished()
     qtbot.addWidget(pydm_drawingimage5)
@@ -603,10 +584,13 @@ def test_pydmdrawingimage_test_properties_and_setters(qtbot):
     assert pydm_drawingimage.aspectRatioMode == Qt.KeepAspectRatioByExpanding
 
 
-@pytest.mark.parametrize("is_pixmap_empty", [
-    True,
-    False,
-])
+@pytest.mark.parametrize(
+    "is_pixmap_empty",
+    [
+        True,
+        False,
+    ],
+)
 def test_pydmdrawingimage_size_hint(qtbot, monkeypatch, is_pixmap_empty):
     """
     Test the size hint of a PyDMDrawingImage object.
@@ -633,20 +617,21 @@ def test_pydmdrawingimage_size_hint(qtbot, monkeypatch, is_pixmap_empty):
         monkeypatch.setattr(QPixmap, "size", lambda *args: QSize(125, 125))
 
     size_hint = pydm_drawingimage.sizeHint()
-    assert size_hint == QSize(100,
-                              100) if is_pixmap_empty else size_hint == pydm_drawingimage._pixmap.size()
+    assert size_hint == QSize(100, 100) if is_pixmap_empty else size_hint == pydm_drawingimage._pixmap.size()
 
 
-@pytest.mark.parametrize("width, height, pen_width", [
-    (7.7, 10.2, 0),
-    (10.2, 7.7, 0),
-    (5.0, 5.0, 0),
-    (10.25, 10.25, 1.5),
-    (10.25, 100.0, 5.125),
-    (100.0, 10.25, 5.125),
-])
-def test_pydmdrawingimage_draw_item(qapp, qtbot, monkeypatch, width, height,
-                                    pen_width):
+@pytest.mark.parametrize(
+    "width, height, pen_width",
+    [
+        (7.7, 10.2, 0),
+        (10.2, 7.7, 0),
+        (5.0, 5.0, 0),
+        (10.25, 10.25, 1.5),
+        (10.25, 100.0, 5.125),
+        (100.0, 10.25, 5.125),
+    ],
+)
+def test_pydmdrawingimage_draw_item(qapp, qtbot, monkeypatch, width, height, pen_width):
     """
     Test the rendering of a PyDMDrawingImage object.
 
@@ -680,16 +665,18 @@ def test_pydmdrawingimage_draw_item(qapp, qtbot, monkeypatch, width, height,
 # # ---------------------
 # # PyDMDrawingRectangle
 # # ---------------------
-@pytest.mark.parametrize("width, height, pen_width", [
-    (7.7, 10.2, 0),
-    (10.2, 7.7, 0),
-    (5.0, 5.0, 0),
-    (10.25, 10.25, 1.5),
-    (10.25, 100.0, 5.125),
-    (100.0, 10.25, 5.125),
-])
-def test_pydmdrawingrectangle_draw_item(qapp, qtbot, monkeypatch, width, height,
-                                        pen_width):
+@pytest.mark.parametrize(
+    "width, height, pen_width",
+    [
+        (7.7, 10.2, 0),
+        (10.2, 7.7, 0),
+        (5.0, 5.0, 0),
+        (10.25, 10.25, 1.5),
+        (10.25, 100.0, 5.125),
+        (100.0, 10.25, 5.125),
+    ],
+)
+def test_pydmdrawingrectangle_draw_item(qapp, qtbot, monkeypatch, width, height, pen_width):
     """
     Test the rendering of a PyDMDrawingRectangle object.
 
@@ -723,16 +710,18 @@ def test_pydmdrawingrectangle_draw_item(qapp, qtbot, monkeypatch, width, height,
 # # ---------------------
 # # PyDMDrawingTriangle
 # # ---------------------
-@pytest.mark.parametrize("width, height, pen_width", [
-    (7.7, 10.2, 0),
-    (10.2, 7.7, 0),
-    (5.0, 5.0, 0),
-    (10.25, 10.25, 1.5),
-    (10.25, 100.0, 5.125),
-    (100.0, 10.25, 5.125),
-])
-def test_pydmdrawingtriangle_draw_item(qapp, qtbot, monkeypatch, width, height,
-                                       pen_width):
+@pytest.mark.parametrize(
+    "width, height, pen_width",
+    [
+        (7.7, 10.2, 0),
+        (10.2, 7.7, 0),
+        (5.0, 5.0, 0),
+        (10.25, 10.25, 1.5),
+        (10.25, 100.0, 5.125),
+        (100.0, 10.25, 5.125),
+    ],
+)
+def test_pydmdrawingtriangle_draw_item(qapp, qtbot, monkeypatch, width, height, pen_width):
     """
     Test the rendering of a PyDMDrawingTriangle object.
 
@@ -762,16 +751,19 @@ def test_pydmdrawingtriangle_draw_item(qapp, qtbot, monkeypatch, width, height,
 
     pydm_drawingtriangle.show()
 
+
 # # -------------------
 # # PyDMDrawingEllipse
 # # -------------------
-@pytest.mark.parametrize("width, height, pen_width", [
-    (5.0, 5.0, 0),
-    (10.25, 10.25, 1.5),
-    (10.25, 100.0, 5.125),
-])
-def test_pydmdrawingellipse_draw_item(qapp, qtbot, monkeypatch, width, height,
-                                      pen_width):
+@pytest.mark.parametrize(
+    "width, height, pen_width",
+    [
+        (5.0, 5.0, 0),
+        (10.25, 10.25, 1.5),
+        (10.25, 100.0, 5.125),
+    ],
+)
+def test_pydmdrawingellipse_draw_item(qapp, qtbot, monkeypatch, width, height, pen_width):
     """
     Test the rendering of a PyDMDrawingEllipse object.
 
@@ -805,13 +797,15 @@ def test_pydmdrawingellipse_draw_item(qapp, qtbot, monkeypatch, width, height,
 # # ------------------
 # # PyDMDrawingCircle
 # # ------------------
-@pytest.mark.parametrize("width, height, expected_radius", [
-    (5.0, 5.0, 2.5),
-    (10.25, 10.25, 5.125),
-    (10.25, 100.0, 5.125),
-])
-def test_pydmdrawingcircle_calculate_radius(qtbot, width, height,
-                                            expected_radius):
+@pytest.mark.parametrize(
+    "width, height, expected_radius",
+    [
+        (5.0, 5.0, 2.5),
+        (10.25, 10.25, 5.125),
+        (10.25, 100.0, 5.125),
+    ],
+)
+def test_pydmdrawingcircle_calculate_radius(qtbot, width, height, expected_radius):
     """
     Test the calculation of a PyDMDrawingCircle's radius.
 
@@ -836,13 +830,15 @@ def test_pydmdrawingcircle_calculate_radius(qtbot, width, height,
     assert calculated_radius == expected_radius
 
 
-@pytest.mark.parametrize("width, height, pen_width", [
-    (5.0, 5.0, 0),
-    (10.25, 10.25, 1.5),
-    (10.25, 100.0, 5.125),
-])
-def test_pydmdrawingcircle_draw_item(qapp, qtbot, monkeypatch, width, height,
-                                     pen_width):
+@pytest.mark.parametrize(
+    "width, height, pen_width",
+    [
+        (5.0, 5.0, 0),
+        (10.25, 10.25, 1.5),
+        (10.25, 100.0, 5.125),
+    ],
+)
+def test_pydmdrawingcircle_draw_item(qapp, qtbot, monkeypatch, width, height, pen_width):
     """
     Test the rendering of a PyDMDrawingCircle object.
 
@@ -897,17 +893,19 @@ def test_pydmdrawingarc_construct(qtbot):
     assert pydm_drawingarc._span_angle == deg_to_qt(90)
 
 
-@pytest.mark.parametrize("width, height, start_angle_deg, span_angle_deg", [
-    (10.333, 11.777, 0, 0),
-    (10.333, 10.333, 0, 0),
-    (10.333, 10.333, 0, 45),
-    (10.333, 11.777, 0, 45),
-    (10.333, 11.777, 0, -35),
-    (10.333, 11.777, 11, 45),
-    (10.333, 11.777, -11, -25),
-])
-def test_pydmdrawingarc_draw_item(qapp, qtbot, monkeypatch, width, height,
-                                  start_angle_deg, span_angle_deg):
+@pytest.mark.parametrize(
+    "width, height, start_angle_deg, span_angle_deg",
+    [
+        (10.333, 11.777, 0, 0),
+        (10.333, 10.333, 0, 0),
+        (10.333, 10.333, 0, 45),
+        (10.333, 11.777, 0, 45),
+        (10.333, 11.777, 0, -35),
+        (10.333, 11.777, 11, 45),
+        (10.333, 11.777, -11, -25),
+    ],
+)
+def test_pydmdrawingarc_draw_item(qapp, qtbot, monkeypatch, width, height, start_angle_deg, span_angle_deg):
     """
     Test the rendering of a PyDMDrawingArc object.
 
@@ -948,7 +946,8 @@ def test_pydmdrawingarc_draw_item(qapp, qtbot, monkeypatch, width, height,
 # # PyDMDrawingPie
 # # ---------------
 @pytest.mark.parametrize(
-    "width, height, pen_width, rotation_deg, start_angle_deg, span_angle_deg", [
+    "width, height, pen_width, rotation_deg, start_angle_deg, span_angle_deg",
+    [
         (10.333, 11.777, 0, 0, 0, 0),
         (10.333, 10.333, 0, 0, 0, 0),
         (10.333, 11.777, 0, 0, 0, 45),
@@ -958,10 +957,11 @@ def test_pydmdrawingarc_draw_item(qapp, qtbot, monkeypatch, width, height,
         (10.333, 11.777, 3, 15.333, 0, -35),
         (10.333, 11.777, 3, 15.333, 11, 45),
         (10.333, 11.777, 3, 15.333, -11, -25),
-    ])
-def test_pydmdrawingpie_draw_item(qapp, qtbot, monkeypatch, width, height, pen_width,
-                                  rotation_deg, start_angle_deg,
-                                  span_angle_deg):
+    ],
+)
+def test_pydmdrawingpie_draw_item(
+    qapp, qtbot, monkeypatch, width, height, pen_width, rotation_deg, start_angle_deg, span_angle_deg
+):
     """
     Test the rendering of a PyDMDrawingPie object.
 
@@ -1005,7 +1005,8 @@ def test_pydmdrawingpie_draw_item(qapp, qtbot, monkeypatch, width, height, pen_w
 # # PyDMDrawingChord
 # # -----------------
 @pytest.mark.parametrize(
-    "width, height, pen_width, rotation_deg, start_angle_deg, span_angle_deg", [
+    "width, height, pen_width, rotation_deg, start_angle_deg, span_angle_deg",
+    [
         (10.333, 11.777, 0, 0, 0, 0),
         (10.333, 10.333, 0, 0, 0, 0),
         (10.333, 11.777, 0, 0, 0, 45),
@@ -1015,10 +1016,11 @@ def test_pydmdrawingpie_draw_item(qapp, qtbot, monkeypatch, width, height, pen_w
         (10.333, 11.777, 3, 15.333, 0, -35),
         (10.333, 11.777, 3, 15.333, 11, 45),
         (10.333, 11.777, 3, 15.333, -11, -25),
-    ])
-def test_pydmdrawingchord_draw_item(qapp, qtbot, monkeypatch, width, height,
-                                    pen_width, rotation_deg, start_angle_deg,
-                                    span_angle_deg):
+    ],
+)
+def test_pydmdrawingchord_draw_item(
+    qapp, qtbot, monkeypatch, width, height, pen_width, rotation_deg, start_angle_deg, span_angle_deg
+):
     """
     Test the rendering of a PyDMDrawingChord object.
 
@@ -1057,16 +1059,18 @@ def test_pydmdrawingchord_draw_item(qapp, qtbot, monkeypatch, width, height,
 
     pydm_drawingchord.show()
 
+
 # # ---------------------
 # # PyDMDrawingPolygon
 # # ---------------------
-@pytest.mark.parametrize("x, y, width, height, num_points, expected_points", [
-    (0, 0, 100, 100, 3, [(50.0, 0),(-25, 43.3012),(-25, -43.3012)]),
-    (0, 0, 100, 100, 4, [(50.0, 0), (0, 50.0), (-50.0, 0), (0, -50.0)])
-])
-def test_pydmdrawingpolygon_calculate_drawing_points(qapp, qtbot, x, y, width,
-                                                      height, num_points,
-                                                      expected_points):
+@pytest.mark.parametrize(
+    "x, y, width, height, num_points, expected_points",
+    [
+        (0, 0, 100, 100, 3, [(50.0, 0), (-25, 43.3012), (-25, -43.3012)]),
+        (0, 0, 100, 100, 4, [(50.0, 0), (0, 50.0), (-50.0, 0), (0, -50.0)]),
+    ],
+)
+def test_pydmdrawingpolygon_calculate_drawing_points(qapp, qtbot, x, y, width, height, num_points, expected_points):
     """
     Test the calculations of the point coordinates of a PyDMDrawingTriangle widget.
 
@@ -1097,9 +1101,7 @@ def test_pydmdrawingpolygon_calculate_drawing_points(qapp, qtbot, x, y, width,
 
     assert drawing.numberOfPoints == num_points
 
-    calculated_points = drawing._calculate_drawing_points(x, y,
-                                                          width,
-                                                          height)
+    calculated_points = drawing._calculate_drawing_points(x, y, width, height)
 
     for idx, p in enumerate(calculated_points):
         assert p.x() == pytest.approx(expected_points[idx][0], 0.1)
@@ -1107,16 +1109,15 @@ def test_pydmdrawingpolygon_calculate_drawing_points(qapp, qtbot, x, y, width,
 
     drawing.show()
 
+
 # # ---------------------
 # # PyDMDrawingPolyline
 # # ---------------------
-@pytest.mark.parametrize("x, y, width, height, num_points, expected_points", [
-    (-1, 27, 389, 3,  2, [(-2, -2),(384, -2)]),
-    (301, 230, 99, 20,  3, [(-1, 18),(-1, -1),(97, -1)])
-])
-def test_pydmdrawingpolyline_getpoints(qapp, qtbot, x, y, width,
-                                                      height, num_points,
-                                                      expected_points):
+@pytest.mark.parametrize(
+    "x, y, width, height, num_points, expected_points",
+    [(-1, 27, 389, 3, 2, [(-2, -2), (384, -2)]), (301, 230, 99, 20, 3, [(-1, 18), (-1, -1), (97, -1)])],
+)
+def test_pydmdrawingpolyline_getpoints(qapp, qtbot, x, y, width, height, num_points, expected_points):
     """
     Test the calculations of the point coordinates of a PyDMDrawingPolyline widget.
 
@@ -1156,18 +1157,28 @@ def test_pydmdrawingpolyline_getpoints(qapp, qtbot, x, y, width,
     drawing.show()
 
 
-@pytest.mark.parametrize("width, height, points, num_points", [
-    (99, 20, ["-1, 18", "-1, -1", "97, -1"], 3),
-    (99, 20, ["-1, 18", "-1, -1", "97, -1", "", " ", "a b"], 3),
-    (99, 20, [[-1, 18], (-1, -1), [97, -1]], 3),
-    (99, 20, [[-1, 18], (-1, -1)], 2),
-    (99, 20, [[-1, 18], (-1, -1.1)], 2),
-    (99, 20, [[-1, 18], "-1, -1.1"], 2),
-    (99, 20, [[-1, 18], "-1, -1.1", "5"], 2),
-    (99, 20, [[-1, 18], "-1, -1.1", ""], 2),
-    (99, 20, [[-1, 18], "-1, -1.1", " "], 2),
-    (99, 20, [[-1, 18],], 0),
-])
+@pytest.mark.parametrize(
+    "width, height, points, num_points",
+    [
+        (99, 20, ["-1, 18", "-1, -1", "97, -1"], 3),
+        (99, 20, ["-1, 18", "-1, -1", "97, -1", "", " ", "a b"], 3),
+        (99, 20, [[-1, 18], (-1, -1), [97, -1]], 3),
+        (99, 20, [[-1, 18], (-1, -1)], 2),
+        (99, 20, [[-1, 18], (-1, -1.1)], 2),
+        (99, 20, [[-1, 18], "-1, -1.1"], 2),
+        (99, 20, [[-1, 18], "-1, -1.1", "5"], 2),
+        (99, 20, [[-1, 18], "-1, -1.1", ""], 2),
+        (99, 20, [[-1, 18], "-1, -1.1", " "], 2),
+        (
+            99,
+            20,
+            [
+                [-1, 18],
+            ],
+            0,
+        ),
+    ],
+)
 def test_pydmdrawingpolyline_setpoints(qapp, qtbot, monkeypatch, width, height, points, num_points):
     """
     Test the rendering of a PyDMDrawingPolyline widget.
@@ -1202,22 +1213,64 @@ def test_pydmdrawingpolyline_setpoints(qapp, qtbot, monkeypatch, width, height,
     drawing.show()
 
 
+@pytest.mark.parametrize("points, num_points", [([[-1, 18], [-1, -1], [97, -1]], 3), ([[-1, 18], [-1, -1]], 2)])
+def test_pydmdrawingpolyline_arrows(qapp, qtbot, points, num_points):
+    """
+    Test the rendering of a PyDMDrawingPolyline widget with arrow options enabled.
+
+    Expectations:
+    The drawing of the widget takes place without any problems.
+
+    Parameters
+    ----------
+    qtbot : fixture
+        Window for widget testing
+    points : [(float, float)]
+        Requested vertices of the polygon.
+    num_points :int
+        The actual number of vertices of the polygon.
+    """
+    drawing = PyDMDrawingPolyline()
+    qtbot.addWidget(drawing)
+
+    # make sure points seutp correctly before drawing arrows
+    drawing.setPoints(points)
+    assert len(drawing.getPoints()) == num_points
+
+    # enable all arrow options
+    drawing._arrow_end_point_selection = True
+    drawing._arrow_start_point_selection = True
+    drawing._arrow_mid_point_selection = True
+    drawing._arrow_mid_point_flipped = True
+    drawing.draw_item(drawing._painter)
+
+    drawing.show()
+
+
 # # ---------------------------
 # # PyDMDrawingIrregularPolygon
 # # ---------------------------
-@pytest.mark.parametrize("num_points, points", [
-    (3, [(-2, -2), (384, -2)]),
-    (3, [(-2, -2), (384, -2), (-2, -2)]),
-    (4, [(-1, 18), (-1, -1), (97, -1)]),
-    (4, [(-1, 18), (-1, -1), "97, -1"]),
-    (4, [(-1, 18), (-1, -1), "97, -1", "-1, 18"]),
-    (4, [(-1, 18), (-1, -1), "97, -1", "-1    18"]),
-    (4, [(-1, 18), (-1, -1), "97, -1", "-1    18", (-1, 18)]),
-    (4, [(-1, 18), (-1, -1), "97, -1", "5"]),
-    (4, [(-1, 18), (-1, -1), "97, -1", ""]),
-    (4, [(-1, 18), (-1, -1), "97, -1", " "]),
-    (None, [(-2, -2), ]),
-])
+@pytest.mark.parametrize(
+    "num_points, points",
+    [
+        (3, [(-2, -2), (384, -2)]),
+        (3, [(-2, -2), (384, -2), (-2, -2)]),
+        (4, [(-1, 18), (-1, -1), (97, -1)]),
+        (4, [(-1, 18), (-1, -1), "97, -1"]),
+        (4, [(-1, 18), (-1, -1), "97, -1", "-1, 18"]),
+        (4, [(-1, 18), (-1, -1), "97, -1", "-1    18"]),
+        (4, [(-1, 18), (-1, -1), "97, -1", "-1    18", (-1, 18)]),
+        (4, [(-1, 18), (-1, -1), "97, -1", "5"]),
+        (4, [(-1, 18), (-1, -1), "97, -1", ""]),
+        (4, [(-1, 18), (-1, -1), "97, -1", " "]),
+        (
+            None,
+            [
+                (-2, -2),
+            ],
+        ),
+    ],
+)
 def test_pydmdrawingirregularpolygon_get_set_resetpoints(qapp, qtbot, num_points, points):
     """
     Test the calculations of the point coordinates of a PyDMDrawingIrregularPolygon widget.
@@ -1257,19 +1310,22 @@ def test_pydmdrawingirregularpolygon_get_set_resetpoints(qapp, qtbot, num_points
 # NEGATIVE TEST CASES
 # --------------------
 
+
 # # -------------
 # # PyDMDrawing
 # # -------------
-@pytest.mark.parametrize("width, height, rotation_deg", [
-    (0, 10.35, 0.0),
-    (10.35, 0, 0.0),
-    (0, 0, 45.0),
-    (-10.5, 10.35, 15.0),
-    (10.35, -5, 17.5),
-    (-10.7, -10, 45.50),
-])
-def test_get_inner_max_neg(qtbot, monkeypatch, caplog, width, height,
-                           rotation_deg):
+@pytest.mark.parametrize(
+    "width, height, rotation_deg",
+    [
+        (0, 10.35, 0.0),
+        (10.35, 0, 0.0),
+        (0, 0, 45.0),
+        (-10.5, 10.35, 15.0),
+        (10.35, -5, 17.5),
+        (-10.7, -10, 45.50),
+    ],
+)
+def test_get_inner_max_neg(qtbot, monkeypatch, caplog, width, height, rotation_deg):
     """
     Test the handling of invalid width and/or height value during the inner rectangle calculations.
 
