@@ -1,13 +1,9 @@
 import os
-import pytest
-from qtpy.QtCore import Qt
-from qtpy.QtWidgets import QApplication
 from ...widgets import PyDMSlider, PyDMTemplateRepeater
 
-test_template_path = os.path.join(
-    os.path.dirname(os.path.realpath(__file__)),
-    "../test_data", "template.ui")
-    
+test_template_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), "../test_data", "template.ui")
+
+
 def test_template_file(qtbot):
     # Test that loading a template and setting data instantiates an instance
     # of the template.
@@ -19,4 +15,4 @@ def test_template_file(qtbot):
     assert template_repeater.count() == len(test_data)
     slider = template_repeater.findChild(PyDMSlider, "bCtrlSlider")
     assert slider is not None
-    assert slider.channel == "ca://{}:BCTRL".format(test_data[0]["devname"])
\ No newline at end of file
+    assert slider.channel == "ca://{}:BCTRL".format(test_data[0]["devname"])
