@@ -24,6 +24,6 @@ def install_connection_inspector(parent, keys=None):
 
     if keys is None:
         keys = QtGui.QKeySequence(QtCore.Qt.ALT + QtCore.Qt.Key_C)
-    shortcut = QtWidgets.QShortcut(keys, parent);
+    shortcut = QtWidgets.QShortcut(keys, parent)
     shortcut.setContext(QtCore.Qt.ApplicationShortcut)
     shortcut.activated.connect(show_inspector)
