@@ -3,16 +3,23 @@ from .baseplot import BasePlotAxisItem
 
 
 class BasePlotAxesModel(QAbstractTableModel):
-    """ The data model for the axes tab in the plot curve editor.
-        Acts as a go-between for the axes in a plot, and QTableView items. """
+    """The data model for the axes tab in the plot curve editor.
+    Acts as a go-between for the axes in a plot, and QTableView items."""
 
     name_for_orientations = {v: k for k, v in BasePlotAxisItem.axis_orientations.items()}
 
     def __init__(self, plot, parent=None):
         super(BasePlotAxesModel, self).__init__(parent=parent)
         self._plot = plot
-        self._column_names = ("Y-Axis Name", "Y-Axis Orientation", "Y-Axis Label",
-                              "Min Y Range", "Max Y Range", "Enable Auto Range", "Log Mode")
+        self._column_names = (
+            "Y-Axis Name",
+            "Y-Axis Orientation",
+            "Y-Axis Label",
+            "Min Y Range",
+            "Max Y Range",
+            "Enable Auto Range",
+            "Log Mode",
+        )
 
     @property
     def plot(self):
@@ -51,7 +58,7 @@ class BasePlotAxesModel(QAbstractTableModel):
         if column_name == "Y-Axis Name":
             return axis.name
         elif column_name == "Y-Axis Orientation":
-            return self.name_for_orientations.get(axis.orientation, 'Left')
+            return self.name_for_orientations.get(axis.orientation, "Left")
         elif column_name == "Y-Axis Label":
             return axis.label_text
         elif column_name == "Min Y Range":
@@ -63,7 +70,6 @@ class BasePlotAxesModel(QAbstractTableModel):
         elif column_name == "Log Mode":
             return axis.log_mode
 
-
     def setData(self, index, value, role=Qt.EditRole):
         if not index.isValid():
             return False
@@ -88,7 +94,7 @@ class BasePlotAxesModel(QAbstractTableModel):
             axis.name = str(value)
         elif column_name == "Y-Axis Orientation":
             if value is None:
-                axis.orientation = 'left'  # The PyQtGraph default is the left axis
+                axis.orientation = "left"  # The PyQtGraph default is the left axis
             else:
                 axis.orientation = str(value)
         elif column_name == "Y-Axis Label":
@@ -107,26 +113,26 @@ class BasePlotAxesModel(QAbstractTableModel):
 
     def headerData(self, section, orientation, role=Qt.DisplayRole):
         if role != Qt.DisplayRole:
-            return super(BasePlotAxesModel, self).headerData(
-                section, orientation, role)
+            return super(BasePlotAxesModel, self).headerData(section, orientation, role)
         if orientation == Qt.Horizontal and section < self.columnCount():
             return str(self._column_names[section])
         elif orientation == Qt.Vertical and section < self.rowCount():
             return section
+
     # End QAbstractItemModel implementation.
 
     def append(self, name):
-        """ Append a row to the table """
+        """Append a row to the table"""
         self.beginInsertRows(QModelIndex(), len(self._plot._axes), len(self._plot._axes))
-        self._plot.addAxis(plot_data_item=None, name=name, orientation='left')
+        self._plot.addAxis(plot_data_item=None, name=name, orientation="left")
         self.endInsertRows()
 
     def removeAtIndex(self, index):
-        """ Removes the axis at the given index on the plot, along with its row in the view """
+        """Removes the axis at the given index on the plot, along with its row in the view"""
         self.beginRemoveRows(QModelIndex(), index.row(), index.row())
         self._plot.removeAxisAtIndex(index.row())
         self.endRemoveRows()
 
     def getColumnIndex(self, column_name):
-        """ Returns the column index of the name. Raises a ValueError if it's not a valid column name """
+        """Returns the column index of the name. Raises a ValueError if it's not a valid column name"""
         return self._column_names.index(column_name)
