@@ -37,6 +37,7 @@ class DictionaryTable(QtWidgets.QTableWidget):
         self.menu = QtWidgets.QMenu(self)
         item = self.itemAt(pos)
         if item is not None:
+
             def copy(*_):
                 copy_to_clipboard(item.text())
 
@@ -48,9 +49,7 @@ class DictionaryTable(QtWidgets.QTableWidget):
             def paste(*_):
                 item.setText(clipboard_text)
 
-            paste_action = self.menu.addAction(
-                f"&Paste: {clipboard_text[:100]}"
-            )
+            paste_action = self.menu.addAction(f"&Paste: {clipboard_text[:100]}")
             paste_action.triggered.connect(paste)
 
             def delete_row(*_):
@@ -73,18 +72,9 @@ class DictionaryTable(QtWidgets.QTableWidget):
 
     @property
     def dictionary(self) -> dict:
-        items = [
-            (self.item(row, 0), self.item(row, 1))
-            for row in range(self.rowCount())
-        ]
-        key_value_pairs = [
-            (key.text() if key else "", value.text() if value else "")
-            for key, value in items
-        ]
-        return {
-            key.strip(): value
-            for key, value in key_value_pairs
-        }
+        items = [(self.item(row, 0), self.item(row, 1)) for row in range(self.rowCount())]
+        key_value_pairs = [(key.text() if key else "", value.text() if value else "") for key, value in items]
+        return {key.strip(): value for key, value in key_value_pairs}
 
     @dictionary.setter
     def dictionary(self, dct):
@@ -110,10 +100,34 @@ class StringListTable(QtWidgets.QTableWidget):
         self.customContextMenuRequested.connect(self._context_menu)
         self.values
 
+        # we let user swap points by dragging one on-top of the other
+        self.setDragEnabled(True)
+        self.setAcceptDrops(True)
+        self.drag_source_row = None
+
+    def startDrag(self, event):
+        self.drag_source_row = self.currentRow()
+        # call super() since we use the default dragging functionality
+        super().startDrag(event)
+
+    def dropEvent(self, event):
+        # don't call super() here, functionality messes with our swapping!
+        source_row = self.drag_source_row
+        target_row = self.indexAt(event.pos()).row()
+        if target_row >= 0 and source_row != target_row:
+            self.swap_rows(source_row, target_row)
+
+    def swap_rows(self, row1, row2):
+        item1 = self.takeItem(row1, 0)
+        item2 = self.takeItem(row2, 0)
+        self.setItem(row1, 0, item2)
+        self.setItem(row2, 0, item1)
+
     def _context_menu(self, pos):
         self.menu = QtWidgets.QMenu(self)
         item = self.itemAt(pos)
         if item is not None:
+
             def copy(*_):
                 copy_to_clipboard(item.text())
 
@@ -148,11 +162,7 @@ class StringListTable(QtWidgets.QTableWidget):
     @property
     def values(self) -> list:
         items = [self.item(row, 0) for row in range(self.rowCount())]
-        return [
-            item.text().strip()
-            for item in items
-            if item is not None
-        ]
+        return [item.text().strip() for item in items if item is not None]
 
     @values.setter
     def values(self, values):
@@ -202,11 +212,7 @@ class _PropertyHelper:
     def save_settings(self):
         value = self.saved_value
         if value is not None:
-            update_property_for_widget(
-                self._property_widget,
-                self._property_name,
-                value
-            )
+            update_property_for_widget(self._property_widget, self._property_name, value)
 
 
 class PropertyRuleEditor(_PropertyHelper, QtWidgets.QPushButton):
@@ -219,6 +225,7 @@ class PropertyRuleEditor(_PropertyHelper, QtWidgets.QPushButton):
 
     def _open_rules_editor(self):
         from .rules_editor import RulesEditor
+
         self._rules_editor = RulesEditor(self._property_widget, parent=self)
         self._rules_editor.exec_()
 
@@ -354,15 +361,18 @@ class BasicSettingsEditor(QtWidgets.QDialog):
             self.property_widgets.append(helper_widget)
 
         buttons_layout = QtWidgets.QHBoxLayout()
-        save_btn = QtWidgets.QPushButton("&Save", parent=self)
-        save_btn.setAutoDefault(True)
-        save_btn.setDefault(True)
-        save_btn.clicked.connect(self.save_changes)
+        self.save_btn = QtWidgets.QPushButton("&Save", parent=self)
+        self.save_btn.setAutoDefault(True)
+        self.save_btn.setDefault(True)
+        self.save_btn.clicked.connect(self.save_changes)
+        self.update_btn = QtWidgets.QPushButton("&Update", parent=self)
+        self.update_btn.clicked.connect(self.save_changes)
         cancel_btn = QtWidgets.QPushButton("&Cancel", parent=self)
         cancel_btn.clicked.connect(self.cancel_changes)
         buttons_layout.addStretch()
         buttons_layout.addWidget(cancel_btn)
-        buttons_layout.addWidget(save_btn)
+        buttons_layout.addWidget(self.update_btn)
+        buttons_layout.addWidget(self.save_btn)
 
         vlayout.addLayout(buttons_layout)
 
@@ -378,10 +388,7 @@ class BasicSettingsEditor(QtWidgets.QDialog):
                 continue
 
             prop_type = getattr(prop, "type", None)
-            helper_widget_cls = self._common_attributes_.get(
-                attr,
-                self._type_to_widget_.get(prop_type, None)
-            )
+            helper_widget_cls = self._common_attributes_.get(attr, self._type_to_widget_.get(prop_type, None))
             if helper_widget_cls is not None:
                 helper_widget = helper_widget_cls(
                     property_widget=self.widget,
@@ -402,10 +409,11 @@ class BasicSettingsEditor(QtWidgets.QDialog):
                     "Failed to save settings for %s.%s = %r",
                     self.widget.objectName(),
                     helper._property_name,
-                    helper.saved_value
+                    helper.saved_value,
                 )
 
-        self.accept()
+        if self.sender() == self.save_btn:
+            self.accept()
 
     @QtCore.Slot()
     def cancel_changes(self):
