@@ -47,83 +47,83 @@ class MultiAxisViewBoxMenu(ViewBoxMenu):
         self.insertAction(self.restoreRangesAction, self.viewAll)
 
     def set3ButtonMode(self):
-        """ Change the mouse left-click functionality to pan the plot """
+        """Change the mouse left-click functionality to pan the plot"""
         super(MultiAxisViewBoxMenu, self).set3ButtonMode()
-        self.sigMouseModeChanged.emit('pan')
+        self.sigMouseModeChanged.emit("pan")
 
     def set1ButtonMode(self):
-        """ Change the mouse left-click functionality to zoom in on the plot """
+        """Change the mouse left-click functionality to zoom in on the plot"""
         super(MultiAxisViewBoxMenu, self).set1ButtonMode()
-        self.sigMouseModeChanged.emit('rect')
+        self.sigMouseModeChanged.emit("rect")
 
     def xAutoClicked(self):
-        """ Update the auto-range value for each view box """
+        """Update the auto-range value for each view box"""
         super().xAutoClicked()
         val = self.ctrl[0].autoPercentSpin.value() * 0.01
         self.sigXAutoRangeChanged.emit(val)
 
     def xManualClicked(self):
-        """ Disable x auto-range for each view box """
+        """Disable x auto-range for each view box"""
         super().xManualClicked()
         self.sigXAutoRangeChanged.emit(False)
 
     def xRangeTextChanged(self):
-        """ Manually set the x-axis range to the user's input. Range will be unchanged if input was invalid """
+        """Manually set the x-axis range to the user's input. Range will be unchanged if input was invalid"""
         super().xRangeTextChanged()
         updated_values = self._validateRangeText(ViewBox.XAxis)
         self.sigXManualRange.emit(*updated_values)
 
     def yAutoClicked(self):
-        """ Update the y auto-range value for each view box """
+        """Update the y auto-range value for each view box"""
         super().yAutoClicked()
         val = self.ctrl[1].autoPercentSpin.value() * 0.01
         self.sigYAutoRangeChanged.emit(val)
 
     def yManualClicked(self):
-        """ Disable y auto-range for each view box """
+        """Disable y auto-range for each view box"""
         super().yManualClicked()
         self.sigYAutoRangeChanged.emit(False)
 
     def yRangeTextChanged(self):
-        """ Manually set the y-axis range to the user's input. Range will be unchanged if input was invalid """
+        """Manually set the y-axis range to the user's input. Range will be unchanged if input was invalid"""
         super().yRangeTextChanged()
         updated_values = self._validateRangeText(ViewBox.YAxis)
         self.sigYManualRange.emit(*updated_values)
 
     def xAutoPanToggled(self, autoPan: bool):
-        """ Toggle the auto pan status of the x-axis """
+        """Toggle the auto pan status of the x-axis"""
         super().xAutoPanToggled(autoPan)
         self.sigAutoPan.emit(autoPan, None)
 
     def xVisibleOnlyToggled(self, autoVisible: bool):
-        """ Toggle the visible only status of autorange for the x-axis """
+        """Toggle the visible only status of autorange for the x-axis"""
         super().xVisibleOnlyToggled(autoVisible)
         self.sigVisibleOnly.emit(autoVisible, None)
 
     def yAutoPanToggled(self, autoPan: bool):
-        """ Toggle the auto pan status of the y-axis """
+        """Toggle the auto pan status of the y-axis"""
         super().yAutoPanToggled(autoPan)
         self.sigAutoPan.emit(None, autoPan)
 
     def yVisibleOnlyToggled(self, autoVisible: bool):
-        """ Toggle the visible only status of autorange for the y-axis """
+        """Toggle the visible only status of autorange for the y-axis"""
         super().yVisibleOnlyToggled(autoVisible)
         self.sigVisibleOnly.emit(None, autoVisible)
 
     def yInvertToggled(self, inverted: bool):
-        """ Toggle the inverted status of the y-axis. """
+        """Toggle the inverted status of the y-axis."""
         super().yInvertToggled(inverted)
         self.sigInvertAxis.emit(ViewBox.YAxis, inverted)
 
     def xInvertToggled(self, inverted: bool):
-        """ Toggle the inverted status of the x-axis """
+        """Toggle the inverted status of the x-axis"""
         super().xInvertToggled(inverted)
         self.sigInvertAxis.emit(ViewBox.XAxis, inverted)
 
     def autoRange(self):
-        """ Sets autorange to True for all elements on the plot """
+        """Sets autorange to True for all elements on the plot"""
         self.sigSetAutorange.emit(True, True)
 
     def restoreRanges(self):
-        """ Restore the original x and y axis ranges for this plot """
+        """Restore the original x and y axis ranges for this plot"""
         self.sigRestoreRanges.emit()
