@@ -7,9 +7,10 @@ import logging
 import warnings
 import hashlib
 from ast import literal_eval
-from qtpy.QtWidgets import QPushButton, QMenu, QMessageBox, QInputDialog, QLineEdit, QWidget
-from qtpy.QtGui import QCursor, QIcon, QMouseEvent
+from qtpy.QtWidgets import QPushButton, QMenu, QMessageBox, QInputDialog, QLineEdit, QWidget, QStyle
+from qtpy.QtGui import QCursor, QIcon, QMouseEvent, QColor
 from qtpy.QtCore import Property, QSize, Qt, QTimer
+from qtpy import QtDesigner
 from .base import PyDMWidget, only_if_channel_set
 from ..utilities import IconFont
 from typing import Optional, Union, List
@@ -35,15 +36,18 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
 
     DEFAULT_CONFIRM_MESSAGE = "Are you sure you want to proceed?"
 
-    def __init__(self, parent: Optional[QWidget] = None, 
-                 command: Optional[Union[str, List[str]]] = None, 
-                 title: Optional[Union[str, List[str]]] = None,
-                 init_channel: Optional[str] = None) -> None:
+    def __init__(
+        self,
+        parent: Optional[QWidget] = None,
+        command: Optional[Union[str, List[str]]] = None,
+        title: Optional[Union[str, List[str]]] = None,
+        init_channel: Optional[str] = None,
+    ) -> None:
         QPushButton.__init__(self, parent)
         PyDMWidget.__init__(self, init_channel=init_channel)
         self.iconFont = IconFont()
         self._icon = self.iconFont.icon("cog")
-        self._warning_icon = self.iconFont.icon('exclamation-circle')
+        self._warning_icon = self.iconFont.icon("exclamation-circle")
         self.setIconSize(QSize(16, 16))
         self.setIcon(self._icon)
         self.setCursor(QCursor(self._icon.pixmap(16, 16)))
@@ -64,6 +68,9 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
         self.process = None
         self._show_icon = True
         self._redirect_output = False
+        # shell allows for more options such as command chaining ("cmd1;cmd2", "cmd1 && cmd2", etc ...),
+        # use of environment variables, glob expansion ('ls *.txt'), etc...
+        self._run_commands_in_full_shell = False
 
         self._password_protected = False
         self._password = ""
@@ -72,7 +79,16 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
 
         self._show_confirm_dialog = False
         self._confirm_message = PyDMShellCommand.DEFAULT_CONFIRM_MESSAGE
-    
+
+        # Standard icons (which come with the qt install, and work cross-platform),
+        # and icons from the "Font Awesome" icon set (https://fontawesome.com/)
+        # can not be set with a widget's "icon" property in designer, only in python.
+        # so we provide our own property to specify standard icons and set them with python in the prop's setter.
+        self._pydm_icon_name = ""
+        # The color of "Font Awesome" icons can be set,
+        # but standard icons are already colored and can not be set.
+        self._pydm_icon_color = QColor(90, 90, 90)
+
     def confirmDialog(self) -> bool:
         """
         Show the confirmation dialog with the proper message in case
@@ -87,7 +103,7 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
         if self._show_confirm_dialog:
             if self._confirm_message == "":
                 self._confirm_message = PyDMShellCommand.DEFAULT_CONFIRM_MESSAGE
-            
+
             msg = QMessageBox()
             msg.setIcon(QMessageBox.Question)
             msg.setText(self._confirm_message)
@@ -99,10 +115,78 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
 
         return True
 
+    @Property(str)
+    def PyDMIcon(self) -> str:
+        """
+        Name of icon to be set from Qt provided standard icons or from the fontawesome icon-set.
+        See "enum QStyle::StandardPixmap" in Qt's QStyle documentation for full list of usable standard icons.
+        See https://fontawesome.com/icons?d=gallery for list of usable fontawesome icons.
+
+        Returns
+        -------
+        str
+        """
+        return self._pydm_icon_name
+
+    @PyDMIcon.setter
+    def PyDMIcon(self, value: str) -> None:
+        """
+        Name of icon to be set from Qt provided standard icons or from the "Font Awesome" icon-set.
+        See "enum QStyle::StandardPixmap" in Qt's QStyle documentation for full list of usable standard icons.
+        See https://fontawesome.com/icons?d=gallery for list of usable "Font Awesome" icons.
+
+        Parameters
+        ----------
+        value : str
+        """
+        if self._pydm_icon_name == value:
+            return
+
+        # We don't know if user is trying to use a standard icon or an icon from "Font Awesome",
+        # so 1st try to create a Font Awesome one, which hits exception if icon name is not valid.
+        try:
+            icon_f = IconFont()
+            i = icon_f.icon(value, color=self._pydm_icon_color)
+            self.setIcon(i)
+        except Exception:
+            icon = getattr(QStyle, value, None)
+            if icon:
+                self.setIcon(self.style().standardIcon(icon))
+
+        self._pydm_icon_name = value
+
+    @Property(QColor)
+    def PyDMIconColor(self) -> QColor:
+        """
+        The color of the icon (color is only applied if using icon from the "Font Awesome" set)
+        Returns
+        -------
+        QColor
+        """
+        return self._pydm_icon_color
+
+    @PyDMIconColor.setter
+    def PyDMIconColor(self, state_color: QColor) -> None:
+        """
+        The color of the icon (color is only applied if using icon from the "Font Awesome" set)
+        Parameters
+        ----------
+        new_color : QColor
+        """
+        if state_color != self._pydm_icon_color:
+            self._pydm_icon_color = state_color
+            # apply the new color
+            try:
+                icon_f = IconFont()
+                i = icon_f.icon(self._pydm_icon_name, color=self._pydm_icon_color)
+                self.setIcon(i)
+            except Exception:
+                return
+
     @Property(bool)
     def showConfirmDialog(self) -> bool:
         """
-        Wether or not to display a confirmation dialog.
+        Whether or not to display a confirmation dialog.
 
         Returns
         -------
@@ -113,7 +197,7 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
     @showConfirmDialog.setter
     def showConfirmDialog(self, value: bool) -> None:
         """
-        Wether or not to display a confirmation dialog.
+        Whether or not to display a confirmation dialog.
 
         Parameters
         ----------
@@ -122,6 +206,29 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
         if self._show_confirm_dialog != value:
             self._show_confirm_dialog = value
 
+    @Property(bool)
+    def runCommandsInFullShell(self) -> bool:
+        """
+        Whether or not to run cmds with Popen's option for running them through a shell subprocess.
+
+        Returns
+        -------
+        bool
+        """
+        return self._run_commands_in_full_shell
+
+    @runCommandsInFullShell.setter
+    def runCommandsInFullShell(self, value: bool) -> None:
+        """
+        Whether or not to run cmds with Popen's option for running them through a shell subprocess.
+
+        Parameters
+        ----------
+        value : bool
+        """
+        if self._run_commands_in_full_shell != value:
+            self._run_commands_in_full_shell = value
+
     @Property(str)
     def confirmMessage(self) -> str:
         """
@@ -154,14 +261,14 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
         status = self._connected
         tooltip = self.restore_original_tooltip()
         if not status:
-            if tooltip != '':
-                tooltip += '\n'
+            if tooltip != "":
+                tooltip += "\n"
             tooltip += "Alarm PV is disconnected."
-            tooltip += '\n'
+            tooltip += "\n"
             tooltip += self.get_address()
 
         self.setToolTip(tooltip)
-        
+
     @Property(str)
     def environmentVariables(self) -> str:
         """
@@ -266,7 +373,7 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
         if self._allow_multiple != value:
             self._allow_multiple = value
 
-    @Property('QStringList')
+    @Property("QStringList")
     def titles(self) -> List[str]:
         return self._titles
 
@@ -275,7 +382,7 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
         self._titles = val
         self._menu_needs_rebuild = True
 
-    @Property('QStringList')
+    @Property("QStringList")
     def commands(self) -> List[str]:
         return self._commands
 
@@ -315,8 +422,7 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
         ----------
         value : str
         """
-        warnings.warn("'PyDMShellCommand.command' is deprecated, "
-                      "use 'PyDMShellCommand.commands' instead.")
+        warnings.warn("'PyDMShellCommand.command' is deprecated, " "use 'PyDMShellCommand.commands' instead.")
         if not self._commands:
             if value:
                 self.commands = [value]
@@ -327,6 +433,7 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
     def passwordProtected(self) -> bool:
         """
         Whether or not this button is password protected.
+
         Returns
         -------
         bool
@@ -338,6 +445,7 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
     def passwordProtected(self, value: bool) -> None:
         """
         Whether or not this button is password protected.
+
         Parameters
         ----------
         value : bool
@@ -351,8 +459,7 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
         Password to be encrypted using SHA256.
 
         .. warning::
-            To avoid issues exposing the password this method
-            always returns an empty string.
+          To avoid issues exposing the password this method always returns an empty string.
 
         Returns
         -------
@@ -377,6 +484,11 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
             # new one, and only updates if the new password is different
             self.protectedPassword = sha.hexdigest()
 
+            # Make sure designer knows it should save the protectedPassword field
+            formWindow = QtDesigner.QDesignerFormWindowInterface.findFormWindow(self)
+            if formWindow:
+                formWindow.cursor().setProperty("protectedPassword", self.protectedPassword)
+
     @Property(str)
     def protectedPassword(self) -> str:
         """
@@ -393,10 +505,10 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
         """
         Setter for the encrypted password.
 
-    	Parameters 
-    	-------
-    	value: str
-    	"""
+        Parameters
+        -------
+        value: str
+        """
         if self._protected_password != value:
             self._protected_password = value
 
@@ -447,13 +559,13 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
         super(PyDMShellCommand, self).mouseReleaseEvent(mouse_event)
 
     def show_warning_icon(self) -> None:
-        """ Show the warning icon.  This is called when a shell command fails
-        (i.e. exits with nonzero status) """
+        """Show the warning icon.  This is called when a shell command fails
+        (i.e. exits with nonzero status)"""
         self.setIcon(self._warning_icon)
         QTimer.singleShot(5000, self.hide_warning_icon)
 
     def hide_warning_icon(self) -> None:
-        """ Hide the warning icon.  This is called on a timer after the warning
+        """Hide the warning icon.  This is called on a timer after the warning
         icon is shown."""
         if self._show_icon:
             self.setIcon(self._icon)
@@ -474,8 +586,7 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
         if not self._password_protected:
             return True
 
-        pwd, ok = QInputDialog().getText(None, "Authentication", "Please enter your password:",
-                                         QLineEdit.Password, "")
+        pwd, ok = QInputDialog().getText(None, "Authentication", "Please enter your password:", QLineEdit.Password, "")
         pwd = str(pwd)
         if not ok or pwd == "":
             return False
@@ -502,7 +613,7 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
 
         Parameters
         ----------
-        command : str 
+        command : str
             Shell command
         """
         if not command:
@@ -517,7 +628,10 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
 
         if (self.process is None or self.process.poll() is not None) or self._allow_multiple:
             cmd = os.path.expanduser(os.path.expandvars(command))
-            args = shlex.split(cmd, posix='win' not in sys.platform)
+            args = shlex.split(cmd, posix="win" not in sys.platform)
+            # when shell enabled, Popen should take the cmds as a single string (not list)
+            if self._run_commands_in_full_shell:
+                args = cmd
             try:
                 logger.debug("Launching process: %s", repr(args))
                 stdout = subprocess.PIPE
@@ -530,10 +644,11 @@ class PyDMShellCommand(QPushButton, PyDMWidget):
                 if self._redirect_output:
                     stdout = None
                 self.process = subprocess.Popen(
-                    args, stdout=stdout, stderr=subprocess.PIPE, env=env_var)
+                    args, stdout=stdout, stderr=subprocess.PIPE, env=env_var, shell=self._run_commands_in_full_shell
+                )
+
             except Exception as exc:
                 self.show_warning_icon()
                 logger.error("Error in shell command: %s", exc)
         else:
             logger.error("Command '%s' already active.", command)
-
